aboutsummaryrefslogtreecommitdiffhomepage
path: root/include/views/SkEvent.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/views/SkEvent.h')
-rw-r--r--include/views/SkEvent.h9
1 files changed, 8 insertions, 1 deletions
diff --git a/include/views/SkEvent.h b/include/views/SkEvent.h
index 0af76fe686..b8fc00ef51 100644
--- a/include/views/SkEvent.h
+++ b/include/views/SkEvent.h
@@ -206,13 +206,20 @@ public:
/**
* Post to the event queue using the event's targetID or target-proc.
* The event will be delivered no sooner than the specified millisecond
* time, as measured by SkTime::GetMSecs().
*
* The event must be dynamically allocated, as ownership is transferred to
* the event queue. It cannot be allocated on the stack or in a global.
*/
void postTime(SkMSec time);
+ /**
+ * Returns ~zero the first time it's called, then returns the number of
+ * milliseconds since the first call. Behavior is undefined if the program
+ * runs more than ~25 days.
+ */
+ static SkMSec GetMSecsSinceStartup();
+
///////////////////////////////////////////////
/** Porting layer must call these functions **/
///////////////////////////////////////////////
@@ -206,13 +206,20 @@ public:
* Post to the event queue using the event's targetID or target-proc.
* The event will be delivered no sooner than the specified millisecond
- * time, as measured by SkTime::GetMSecs().
+ * time, as measured by GetMSecsSinceStartup().
*
* The event must be dynamically allocated, as ownership is transferred to